.. currentmodule:: xrft

#############
API reference
#############

This page provides an auto-generated summary of xrft's API. For more details
and examples, refer to the relevant chapters in the main part of the
documentation.


.. note::

  None of xrft's functions will work correctly in the presence of NaNs or
  missing data. It's the user's responsibility to ensure data are free of NaN
  or that NaNs have been filled somehow.

xrft
====

.. automodule:: xrft.xrft
  :members:

detrend
=======

You also may wish to use xrft's detrend function on its own.

.. automodule:: xrft.detrend
  :members:
